@@ -1,5 +1,5 @@
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -45,7 +45,8 @@ class Teacher(abstract.Teacher):
             self.m_timeout_handle = None
 
         if self.get_bool('config/picky_on_new_question') \
-                and self.q_status in (const.QSTATUS_NEW, const.QSTATUS_WRONG):
+                and self.q_status in (const.QSTATUS_NEW, const.QSTATUS_WRONG) \
+                and (not self.get_bool('one_chance_only')):
             return Teacher.ERR_PICKY
 
         v = []
