@@ -1,9 +1,8 @@
-#!/usr/bin/env python
-
+#!/usr/bin/python2.1
 import profile, os
 import sys, types
 
-#sys.path.append("/home/tom/lib/python2.0/site-packages")
+sys.path.append("/usr/lib/python2.1/site-packages")
 
 if os.getcwd()[-4:] == "test":
    sys.path.append("..")
@@ -30,19 +29,25 @@ def vis():
 
 
 def pass1():
-        for n in range(2):
+        for n in range(30):
                 score = mpd.parser.parse_to_score_object(music)
                 eng = score.get_engravers(20)
-score = mpd.parser.parse_to_score_object(music)
 def pass2():
-    for x in range(5):
-        eng = score.get_engravers(20)
+    for x in range(20):
+        score = mpd.parser.parse_to_score_object(music)
+        #eng = score.get_engravers(20)
 
 import time
 t1 = time.clock()
-#profile.run("pass2()", "profile.txt")
-pass1()
+if 0:
+    os.system("rm -f profile.txt")
+    profile.run("pass2()", "profile.txt")
+    vis()
+else:
+    #import gc
+    #gc.set_debug(gc.DEBUG_LEAK)
+    pass1()
+    #gc.collect()
 t2 = time.clock()
 print t2-t1
-#vis()
 
